<template>
  <div class="common-page-shadow">
    <div class="common-search-container" ref="contentPanel">
      <el-form
        ref="form"
        :model="searchForm"
        label-width="auto"
        type="flex"
        justify="left"
      >
        <el-row :gutter="25">
          <el-col :span="7">
            <el-form-item label="收费站">
              <el-select
                clearable
                size="small"
                v-model="searchForm.tollStationId"
                filterable
                placeholder="收费站"
              >
                <el-option
                  v-for="(item, index) in tollStationData"
                  :key="index"
                  :label="item.name"
                  :value="item.id"
                >
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="统计日期">
              <el-date-picker
                size="small"
                v-model="transDate"
                type="monthrange"
                range-separator="至"
                start-placeholder="开始月份"
                end-placeholder="结束月份"
                format="yyyy-MM"
                value-format="yyyy-MM"
                :picker-options="pickerOptions"
                style="width: 100%"
              >
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="2">
            <el-button
              size="small"
              icon="el-icon-search"
              type="primary"
              class="btn btn-plus"
              @click="handleSearch"
            >
              {{ this.$t('common.search') }}
            </el-button>
          </el-col>
          <el-col :span="2">
            <el-button
              size="small"
              icon="el-icon-refresh-right"
              class="btn btn-plus"
              @click="clearSearchForm"
            >
              重置
            </el-button>
          </el-col>
        </el-row>
      </el-form>
      <div class="download-btn">
        <el-row :gutter="10">
          <el-col :span="14">
            <el-button
              size="small"
              class="btn btn-plus"
              icon="el-icon-upload"
              plain
              :loading="downLoading"
              @click="handleOutput"
              :disabled="!tableData.length"
              >导出</el-button
            >
          </el-col>
        </el-row>
      </div>
    </div>
    <el-row
      class="common-table-container flex searchPanel"
      :style="SearchPanel"
    >
      <el-col :span="24" class="common-table-wrapper">
        <!-- LJ：表格高度自适应需配合样式  btn-pagenation 有按钮有分页  btngroup只有按钮  pagenation只有分页 -->
        <div class="common-table-content nation">
          <el-table
            :border="true"
            stripe
            fit
            size="mini"
            v-loading="tableLoading"
            ref="multipleSelection"
            :data="tableData"
            height="100%"
            show-summary
            @selection-change="handleSelectionChange"
          >
            <el-table-column
              prop="transDate"
              label="日期"
              align="left"
              width="120px"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="exitusMoney"
              show-overflow-tooltip
              align="left"
              label="出口(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="exitusCash"
              show-overflow-tooltip
              align="left"
              label="现金(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="exitusOnline"
              show-overflow-tooltip
              align="left"
              label="非现金(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="exitusEtc"
              show-overflow-tooltip
              align="left"
              label="ETC(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="exitusNoEtc"
              show-overflow-tooltip
              align="left"
              label="非ETC(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="inletMoney"
              show-overflow-tooltip
              align="left"
              label="入口(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="inletCash"
              show-overflow-tooltip
              align="left"
              label="现金(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="inletOnline"
              show-overflow-tooltip
              align="left"
              label="非现金(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="inletEtc"
              show-overflow-tooltip
              align="left"
              label="ETC(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="inletNoEtc"
              show-overflow-tooltip
              align="left"
              label="非ETC(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="allMoney"
              show-overflow-tooltip
              align="left"
              label="出入口(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="allCash"
              show-overflow-tooltip
              align="left"
              label="现金(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="allOnline"
              show-overflow-tooltip
              align="left"
              label="非现金(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="allEtc"
              show-overflow-tooltip
              align="left"
              label="ETC(元)"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="allNoEtc"
              show-overflow-tooltip
              align="left"
              label="非ETC(元)"
              resizable
            >
            </el-table-column>
          </el-table>
        </div>
      </el-col>
    </el-row>
  </div>
</template>
    
    <script>
import {TableMixin} from '@/mixins/tableMixin'
import report from '@/api/DataReport/Report.js'
import tollStationManagement from '@/api/BasicDataManagement/tollStationManagement.js'
import moment from 'moment'
export default {
  name: 'chargeDataReport',
  mixins: [TableMixin],
  data() {
    return {
      disabledDetils: false,
      currentPage: 1,
      tableMaxHeight: 400,
      loading: false,
      tableLoading: false,
      tableData: [],
      multipleSelection: [],
      params: {
        pageBean: {
          page: 1,
          pageSize: -1,
          total: 0,
        },
      },
      searchForm: {}, // 顶部搜索对象
      tollStationData: [],
      tollStationId: '',
      value: '',
      pickDate: '', // 存放getPickDate获取的数据
      pickerOptions: {
        onPick: this.getPickDate,
        disabledDate: this.disabledDate,
      },
      downLoading: false,
      Nowmonth: '',
      Nowdate: [],
      transDate: [],
    }
  },
  created() {
    let startDate = moment().startOf('month').format('YYYY-MM-DD HH:mm:ss')
    let endDate = moment()
      .startOf('month')
      .subtract('month', -1)
      .format('YYYY-MM-DD HH:mm:ss')
    this.Nowdate = [startDate, endDate]
    var date = new Date()
    this.Nowmonth = date.format('yyyy-MM')
    this.tollStationId = sessionStorage.getItem('tollStationId')
    this.searchForm.tollStationId = this.tollStationId
    this.transDate = [this.Nowmonth, this.Nowmonth]

    this.loadTollStation()
    this.loadData(1)
  },
  methods: {
    clearSearchForm() {
      this.searchForm = {}
      this.transDate = [this.Nowmonth, this.Nowmonth]
      this.searchForm.tollStationId = this.tollStationId
      this.searchForm.transDate = this.transDate
      this.handleSearch()
    },
    // 导出数据
    handleOutput() {
      this.downLoading = true
      report.OutPuttrafficCash(this.params).then((res) => {
        const content = res
        const blob = new Blob([content])
        const fileName = `收费站出入口收费数据对比.xls`
        const elink = document.createElement('a')
        elink.download = fileName
        elink.style.display = 'none'
        elink.href = URL.createObjectURL(blob)
        document.body.appendChild(elink)
        elink.click()
        URL.revokeObjectURL(elink.href) // 释放URL 对象
        document.body.removeChild(elink)
        this.downLoading = false
      })
    },
    //获取数据
    loadData(page) {
      if (!this.params.querys) {
        let querys = []
        querys.push(
          {
            group: 'main',
            operation: 'LIKE',
            parentGroup: '',
            property: 'toll_station_id_',
            relation: 'AND',
            value: this.tollStationId,
          },
          {
            group: 'main',
            operation: 'BETWEEN',
            parentGroup: '',
            property: 'transDate',
            relation: 'AND',
            value: this.Nowdate,
          }
        )
        this.params.querys = querys
      }
      if (page) this.params.pageBean.page = page
      this.tableLoading = true
      report.querytrafficCash(this.params).then((res) => {
        this.tableLoading = false
        const data = (res && res.data) || {}
        this.tableData = res.value || []
        if (data.page) {
          this.params.pageBean = {
            page: data.page,
            pageSize: data.pageSize,
            total: data.total,
          }
        }
      })
    },
    getPickDate(pick) {
      this.pickDate = pick
    },
    disabledDate(date) {
      const {minDate, maxDate} = this.pickDate
      if (minDate && !maxDate) {
        const diff = Math.abs(minDate.valueOf() - date.valueOf())
        if (diff > 1000 * 3600 * 24 * 90) {
          return true
        }
      }
    },
    // 获取收费站数据
    loadTollStation() {
      tollStationManagement.queryTollStation(this.allData).then((res) => {
        let obj = []
        for (let i = 0; i < res.data.rows.length; i++) {
          obj = {
            id: res.data.rows[i].id,
            name: res.data.rows[i].name,
            roadName: res.data.rows[i].roadSegmentName,
            roadId: res.data.rows[i].roadSegmentId,
          }
          this.tollStationData.push(obj)
        }
      })
    },
    // 顶部搜索
    handleSearch() {
      if (this.transDate) {
        let startTime = this.transDate[0]
        let endTime = this.transDate[1]
        let year = parseInt(endTime.slice(0, 4))
        let month = parseInt(endTime.slice(5, 7))
        if (month == 12) {
          month = 1
          year = year + 1
        } else {
          month = month + 1
        }
        if (month < 10) {
          endTime = year + '-0' + month + '-01 00:00:00'
        } else {
          endTime = year + '-' + month + '-01 00:00:00'
        }

        startTime = startTime + '-01 00:00:00'

        this.searchForm.transDate = [startTime, endTime]
      }

      let obj = this.searchForm
      let querys = []
      for (let i in obj) {
        if (obj[i] && i == 'tollStationId') {
          querys.push({
            group: 'main',
            operation: 'LIKE',
            parentGroup: '',
            property: 'toll_station_id_',
            relation: 'AND',
            value: obj[i],
          })
        } else if (obj[i] && i == 'transDate') {
          querys.push({
            group: 'main',
            operation: 'BETWEEN',
            parentGroup: '',
            property: i,
            relation: 'AND',
            value: obj[i],
          })
        }
      }

      this.params.querys = querys

      this.loadData(1)
    },
  },

  mounted() {
    this.calcTableHeight()
    this.$root.$on('resize', () => {
      this.calcTableHeight(500)
    })
  },
  computed: {
    SearchPanel() {
      return {
        '--searchPanel': this.searchPanel + 'px',
      }
    },
  },
}
</script>
    
    <style lang="scss" scoped>
// /deep/.el-table{
//     overflow: auto;
//   }
//   /deep/.el-table__body-wrapper,
//   .el-table__header-wrapper,
//   .el-table__footer-wrapper{
//     overflow:visible;
//   }
//   /deep/.el-table::after{
//     position: relative !important;
//   }
    
    
    </style>
